autowisp.tests.test_calibrate module — AutoWISP documentation

# autowisp.tests.test_calibrate module

## Class Inheritance Diagram

Test cases for image calibration.

class autowisp.tests.test_calibrate.TestCalibrate(methodName='runTest')

  Bases: `FITSTestCase`

  Test cases for image calibration.

  _test_calibration(input_imtype, **masters)

    Perform a calibration step and test outputs match expectations.

  test_bias_calibration()

    Check if bias calibration works as expected.

  test_dark_calibration()

    Check if dark calibration works as expected.

  test_flat_calibration()

    Check if flat calibration works as expected.

  test_object_calibration()

    Check if flat calibration works as expected.